The Project Diamond application passes a JSON payload from one node to the next, using different server
Every activity is logged to a MongoDB using node5's Node5 log method. P2P payload time is calculated 
using Team 1's p2p module; the total P2P time is also calculated in node1 since it is the last node to 
receive a payload.
